@@ -1,9 +1,12 @@
+// -*- Mode: c++; c-basic-offset: 4; tab-width: 4; -*-
+
 
 /****************************************************************************** 
  * 
  *  file:  Visitor.h
  * 
  *  Copyright (c) 2003, Michael E. Smoot .
+ *  Copyright (c) 2017, Google LLC
  *  All rights reserved.
  * 
  *  See the file COPYING in the top directory of this distribution for
@@ -43,9 +46,10 @@ class Visitor
 		virtual ~Visitor() { }
 
 		/**
-		 * Does nothing. Should be overridden by child.
+		 * This method (to implemented by children) will be
+		 * called when the visitor is visited.
 		 */
-		virtual void visit() { }
+		virtual void visit() = 0;
 };
 
 }
